@@ -13,6 +13,43 @@ from .common import _getCitation
 from .extending import extend
 
 
+@extend(ee.image.Image)
+def __getitem__(self, key):
+    '''Gets the band of the image according to the specified key.
+
+    Parameters
+    ----------
+    self : ee.Image
+        Image to get the bands from.
+    key : numeric | string | list[numeric] | list[string] | slice
+        Key used to get the specified band. If numeric, it gets the band at that index. If string, it gets the band with that name
+        or that matches with regex. If list, it gets multiple bands. If slice, it calls the slice() method (the step parameter is ignored).
+
+    Returns
+    -------
+    ee.Image
+        Image with the selected bands.
+    '''
+    if isinstance(key,slice):
+
+        if key.start == None:
+            start = 0
+        else:
+            start = key.start
+
+        if key.stop == None:
+            stop = self.bandNames().size()
+        else:
+            stop = key.stop
+
+        selected = self.slice(start,stop)
+
+    else:
+        selected = self.select(key)
+
+    return selected
+
+
 @extend(ee.image.Image)
 def __add__(self, other):
     """Computes the addition between two images.
@@ -620,47 +657,11 @@ def index(
             - 'water' : Compute all water indices.
             - 'snow' : Compute all snow indices.
             - 'drought' : Compute all drought indices.
+            - 'urban' : Compute all urban (built-up) indices.
             - 'kernel' : Compute all kernel indices.
             - 'all' : Compute all indices listed below.
-        Vegetation indices:
-            - 'BNDVI' : Blue Normalized Difference Vegetation Index.
-            - 'CIG' : Chlorophyll Index - Green.
-            - 'CVI' : Chlorophyll Vegetation Index.
-            - 'EVI' : Enhanced Vegetation Index.
-            - 'EVI2' : Two-Band Enhanced Vegetation Index.
-            - 'GARI' : Green Atmospherically Resistant Vegetation Index.
-            - 'GBNDVI' : Green-Blue Normalized Difference Vegetation Index.
-            - 'GEMI' : Global Environment Monitoring Index.
-            - 'GLI' : Green Leaf Index.
-            - 'GNDVI' : Green Normalized Difference Vegetation Index.
-            - 'GRNDVI' : Green-Red Normalized Difference Vegetation Index.
-            - 'GVMI' : Global Vegetation Moisture Index.
-            - 'MNDVI' : Modified Normalized Difference Vegetation Index.
-            - 'NDVI' : Normalized Difference Vegetation Index.
-            - 'NGRDI' : Normalized Green Red Difference Index.
-            - 'RVI' : Ratio Vegetation Index.
-            - 'SAVI' : Soil-Adjusted Vegetation Index.
-            - 'VARI' : Visible Atmospherically Resistant Index.
-        Burn and fire indices:
-            - 'BAI' : Burned Area Index.
-            - 'BAIS2' : Burned Area Index for Sentinel 2.
-            - 'CSIT' : Char Soil Index Thermal.
-            - 'NBR' : Normalized Burn Ratio.
-            - 'NBRT' : Normalized Burn Ratio Thermal.
-            - 'NDVIT' : Normalized Difference Vegetation Index Thermal
-            - 'SAVIT' : Soil-Adjusted Vegetation Index Thermal.
-        Water indices:
-            - 'MNDWI' : Modified Normalized Difference Water Index.
-            - 'NDWI' : Normalized Difference Water Index.
-        Snow indices:
-            - 'NDSI' : Normalized Difference Snow Index.
-        Drought indices:
-            - 'NDDI' : Normalized Difference Drought Index.
-        Kernel indices:
-            - 'kEVI' : Kernel Enhanced Vegetation Index.
-            - 'kNDVI' : Kernel Normalized Difference Vegetation Index.
-            - 'kRVI' : Kernel Ratio Vegetation Index.
-            - 'kVARI' : Kernel Visible Atmospherically Resistant Index.
+        Awesome Spectral Indices for GEE:
+            Check the complete list of indices `here <https://awesome-ee-spectral-indices.readthedocs.io/en/latest/list.html>`_.
     G : float, default = 2.5
         Gain factor. Used just for index = 'EVI'.
     C1 : float, default = 6.0
@@ -799,47 +800,11 @@ def spectralIndices(
             - 'water' : Compute all water indices.
             - 'snow' : Compute all snow indices.
             - 'drought' : Compute all drought indices.
+            - 'urban' : Compute all urban (built-up) indices.
             - 'kernel' : Compute all kernel indices.
             - 'all' : Compute all indices listed below.
-        Vegetation indices:
-            - 'BNDVI' : Blue Normalized Difference Vegetation Index.
-            - 'CIG' : Chlorophyll Index - Green.
-            - 'CVI' : Chlorophyll Vegetation Index.
-            - 'EVI' : Enhanced Vegetation Index.
-            - 'EVI2' : Two-Band Enhanced Vegetation Index.
-            - 'GARI' : Green Atmospherically Resistant Vegetation Index.
-            - 'GBNDVI' : Green-Blue Normalized Difference Vegetation Index.
-            - 'GEMI' : Global Environment Monitoring Index.
-            - 'GLI' : Green Leaf Index.
-            - 'GNDVI' : Green Normalized Difference Vegetation Index.
-            - 'GRNDVI' : Green-Red Normalized Difference Vegetation Index.
-            - 'GVMI' : Global Vegetation Moisture Index.
-            - 'MNDVI' : Modified Normalized Difference Vegetation Index.
-            - 'NDVI' : Normalized Difference Vegetation Index.
-            - 'NGRDI' : Normalized Green Red Difference Index.
-            - 'RVI' : Ratio Vegetation Index.
-            - 'SAVI' : Soil-Adjusted Vegetation Index.
-            - 'VARI' : Visible Atmospherically Resistant Index.
-        Burn and fire indices:
-            - 'BAI' : Burned Area Index.
-            - 'BAIS2' : Burned Area Index for Sentinel 2.
-            - 'CSIT' : Char Soil Index Thermal.
-            - 'NBR' : Normalized Burn Ratio.
-            - 'NBRT' : Normalized Burn Ratio Thermal.
-            - 'NDVIT' : Normalized Difference Vegetation Index Thermal
-            - 'SAVIT' : Soil-Adjusted Vegetation Index Thermal.
-        Water indices:
-            - 'MNDWI' : Modified Normalized Difference Water Index.
-            - 'NDWI' : Normalized Difference Water Index.
-        Snow indices:
-            - 'NDSI' : Normalized Difference Snow Index.
-        Drought indices:
-            - 'NDDI' : Normalized Difference Drought Index.
-        Kernel indices:
-            - 'kEVI' : Kernel Enhanced Vegetation Index.
-            - 'kNDVI' : Kernel Normalized Difference Vegetation Index.
-            - 'kRVI' : Kernel Ratio Vegetation Index.
-            - 'kVARI' : Kernel Visible Atmospherically Resistant Index.
+        Awesome Spectral Indices for GEE:
+            Check the complete list of indices `here <https://awesome-ee-spectral-indices.readthedocs.io/en/latest/list.html>`_.
     G : float, default = 2.5
         Gain factor. Used just for index = 'EVI'.
     C1 : float, default = 6.0
